@@ -7,7 +7,7 @@ fn spwan() {
         .detailed_message("interesting details")
         .button(Button::detailed("show me more"))
         .button(Button::simple("simple", "false"))
-        .button(Button::dismiss("go away", "yes"))
+        .button(Button::dismiss("go away", "true"))
         .button(Button::override_default_dismiss("Y"))
         .edge(Edge::Bottom)
         .spawn()
@@ -23,7 +23,7 @@ fn spwan_async() {
             .detailed_message("interesting details")
             .button(Button::detailed("show me more"))
             .button(Button::simple("simple", "false"))
-            .button(Button::dismiss("go away", "yes"))
+            .button(Button::dismiss("go away", "true"))
             .button(Button::override_default_dismiss("Y"))
             .edge(Edge::Bottom)
             .spawn()
